diff src/emacs.c @ 92892:dc8ef1d9d71d

(main): Revert previous change. (standard_args): Revert -internal-script back to -scriptload, and remove the long-option form.
author Glenn Morris <rgm@gnu.org>
date Fri, 14 Mar 2008 02:40:13 +0000
parents eb36bc19579d
children 7a919633882d
line wrap: on
line diff
--- a/src/emacs.c	Fri Mar 14 02:38:45 2008 +0000
+++ b/src/emacs.c	Fri Mar 14 02:40:13 2008 +0000
@@ -1133,10 +1133,10 @@
   if (argmatch (argv, argc, "-script", "--script", 3, &junk, &skip_args))
     {
       noninteractive = 1;	/* Set batch mode.  */
       /* Convert --script to -internal-script, un-skip it, and sort again
 	 so that it will be handled in proper sequence.  */
       /* FIXME broken for --script=FILE - is that supposed to work?  */
-      argv[skip_args - 1] = "-internal-script";
+      argv[skip_args - 1] = "-scriptload";
       skip_args -= 2;
       sort_args (argc, argv);
     }
@@ -1872,11 +1872,11 @@
   { "-directory", 0, 0, 1 },
   { "-l", "--load", 0, 1 },
   { "-load", 0, 0, 1 },
-  /* This was --scriptload, but that confuses sort_args, because then
-     the --script long option seems to match twice; ie you can't have
-     a long option which is a prefix of another long option.
-     In any case, this is entirely an internal option.  */
-  { "-internal-script", "--internal-script", 0, 1 },
+  /* This has no longname, because using --scriptload confuses sort_args,
+     because then the --script long option seems to match twice; ie
+     you can't have a long option which is a prefix of another long
+     option.  In any case, this is entirely an internal option.  */
+  { "-scriptload", NULL, 0, 1 },
   { "-f", "--funcall", 0, 1 },
   { "-funcall", 0, 0, 1 },
   { "-eval", "--eval", 0, 1 },
@@ -1133,10 +1133,10 @@
     {
       noninteractive = 1;	/* Set batch mode.  */
-      /* Convert --script to -internal-script, un-skip it, and sort again
+      /* Convert --script to -scriptload, un-skip it, and sort again
 	 so that it will be handled in proper sequence.  */
       /* FIXME broken for --script=FILE - is that supposed to work?  */